#ifndef SED1330_H
#define SED1330_H

#include <avr/pgmspace.h>
#include <stdio.h>
#include <stdbool.h>
#include <math.h>
#include <avr/io.h>

#define GLCD_DATA     PORTC  /* Grafic LCD Data Port C   */
#define PIN_DATA      PINC     
#define DDR_DATA      DDRC

#define GLCD_CTRL     PORTA  /* Grafic LCD Control Port A*/
#define PIN_CTRL      PINA
#define DDR_CTRL      DDRA

#define GLCD_COMMAND   6     /* A0 Pin       (Control Port Bit 0) */
#define GLCD_CS        5     /* Chip Select  (Control Port Bit 1) */
#define GLCD_WR        2     /* WR Pin       (Control Port Bit 2) */
#define GLCD_RD        1     /* WD Pin       (Control Port Bit 3) */
#define GLCD_RESET     0     /* Reset Pin    (Control Port Bit 4) */



#define GLCD_RESX       256   /* Grafic resolution X */
#define GLCD_RESY       128   /* Grafic resolution Y */
#define GLCD_CHARPERROW 42    /* maximum is ( GLCD_RESX / GLCD_CHARWIDTH ) */
#define GLCD_CHARROWS   16    /* should be calculated from RESY/CHARHEIGHT */
#define GLCD_CHARWIDTH  6     /* = GLCD_RESX / GLCD_CHARPERROW */
#define GLCD_CHARHEIGHT 8


// *************************************************************
// Types 
// *************************************************************
typedef enum DrawMode {
  on,    // Set Pixel
  off,   // Clear Pixel 
  fill,  // fill Circel, rectangle etc.
  clear  // clear circle, rectangle etc.
} 
drawmode;

// *************************************************************
// User Functions 
// *************************************************************

void GLCD_Init (void);            /* Initialize Display Controler */
void GLCD_Reset(void);            /* Reset Display Controler.     */
void GLCD_ClearText(void);        /* Clear Text Screen    */
void GLCD_Text(unsigned char x, unsigned char y, unsigned char *myText);
void GLCD_Char(unsigned char myChar);
int  GLCD_PrintChar(char myChar); /* for using STDIO in avr-libc */

void GLCD_ClearGraph(void); /* Clear Graphic Screen */
void GLCD_Pixel (int x,int y, drawmode show);
void GLCD_Line  (int x1, int y1, int x2, int y2, drawmode show);
void GLCD_Circle(int x, int y, int radius, drawmode show);
void GLCD_Rectangle (int x1,int y1,int x2,int y2,drawmode show);
void GLCD_DegreeLine(int x,int y, int degree, int inner_radius, int outer_radius, drawmode show);
void GLCD_DrawPicture(int x, int y, int width, int high,PGM_P pt);

#endif
