/*************************************************************************
Title:    Testing AVR Sed1330 functions
Author:   TestCode
**************************************************************************/

#include <stdio.h>
#include <stdbool.h>
#include <math.h>
#include <avr/io.h>
#include <avr/pgmspace.h>
#include <avr/signal.h>
#include <avr/interrupt.h>
#include "sed1330.h"
#include "Test_Lcd.h"


/***********************************/
/* constant definitions            */
/***********************************/
 const char welcome1[] PROGMEM = " Welcome to SED1330/ATmega16 Terminal\r";
 const char welcome2[] PROGMEM = " Graphic Lcd Test\r";
 const char nothingToDo[] PROGMEM = " Welcome to Graphic Lcd Display\r";
 const char textLine1[] PROGMEM = "A Line of Text\r";
 const char textLine2[] PROGMEM = "A second Line of Text\r";
 const char textLine3[] PROGMEM = "A third Line of Text\r";
 const char textLine4[] PROGMEM = "A fourth Line of Text\r";

 const char crlf[] PROGMEM = "\r\n";

int sec = 0;
int min = 0;

//No used in this example
void wait_until_key_pressed(void)
{
    unsigned char i, j;
    

    do {
        loop_until_bit_is_clear(PIND,PIND2);     /* wait until key is pressed */
        
        for (i=0;i<255;i++) for (j=0;j<255;j++); /* debounce */
            
        if (bit_is_clear(PIND,PIND2)) break;
    } while (1);
    loop_until_bit_is_set(PIND,PIND2);            /* wait until key is released */
}


int main(void)
{
unsigned char c;
int i;
    DDRD &=~ (1 << PIND2);        /* Pin PD2 input              */
    PORTD |= (1 << PIND2);        /* Pin PD2 pull-up enabled    */

// Disable all interrupts
  cli();
    // Set up timer 1 for about 1 second
    TCCR1B = 0x00;
    TCNT1H = 0xE3;
    TCNT1L = 0xE1;
    OCR1AH = 0x1C;
    OCR1AL = 0x1F;
    OCR1BH = 0x1C;
    OCR1BL = 0x1F;
    TCCR1A = 0x00;
    TCCR1B = 0x05;
    MCUCR = 0x00; //interrupt handle
    TIMSK = 0x80;



    /* Init LCD Dispay */
    GLCD_Reset();
    GLCD_Init();
    GLCD_ClearText();
    GLCD_ClearGraph();
    
    /* Set STDOUT to LCD */
    stdout = fdevopen(GLCD_PrintChar,NULL,0);

   /* 
    * Test 1:  write text to display
    */
    
   /* clear Graph & Text display and home cursor */
   GLCD_ClearText();
   GLCD_ClearGraph();
   GLCD_Text(5, 0,"");  // Just set Cursor
   puts_P(nothingToDo);

   for (c=1  ; c < 239; c++) { GLCD_Pixel(c,12, on); }

   for (c=12 ; c < 57 ; c++) { GLCD_Pixel(238,c , on); }       
   for (c=12 ; c < 57 ; c++) { GLCD_Pixel(121,c , on); }        
   for (c=12 ; c < 57 ; c++) { GLCD_Pixel(1  ,c,  on); }       
     
   for (c=1  ; c < 239; c++) { GLCD_Pixel(c  ,57, on); }       

   GLCD_Text(21,2,"Test 1: Line 2");       
   GLCD_Text(21,3,"Test 2: Line 3");       
   GLCD_Text(21,4,"Test 3: Line 4");  
   GLCD_Text(5,4,"9");
   GLCD_Text(14,4,"3");    
   GLCD_Text(21,5,"Test 4: Line 5");       
   GLCD_Text(21,6,"Test 5: Line 6");       
   puts("\r");
   puts("\r");       
   puts_P(welcome1);
   puts_P(welcome2);
   GLCD_Circle(60,34, 22, on);
   i = 0;
   while (i < 360)
   {
     GLCD_DegreeLine(60,34,i,22,22+2,on);
     i = i + 30;
   }
       
   GLCD_Rectangle (190,95,230,125 ,fill);
   GLCD_Rectangle (150,95,190,125 ,on);
   GLCD_Rectangle (110,95,150,125 ,on);       
   GLCD_Rectangle ( 70,95,110,125 ,on);
   GLCD_Rectangle ( 30,95, 70,125 ,fill);
   
   GLCD_Line  (150, 95 ,190,125, on);
   GLCD_Line  (190, 95 ,150,125, on);              
   GLCD_Line  (110, 95 ,150,125, on);
   GLCD_Line  (150, 95 ,110,125, on);            
   GLCD_Line  ( 70, 95 ,110,125, on);
   GLCD_Line  (110, 95 , 70,125, on);            
   GLCD_Text(1,10,"Hello World");              

    // Enable timer 1 overflow interrupts.
    timer_enable_int(_BV(TOIE1));
    sei();
    for (;;) {                           // loop forever         
        // wait until push button PD2 (INT0) is pressed 
       wait_until_key_pressed();
   }
}


/* Timer 1 Overflow Interrupt */
INTERRUPT (SIG_OVERFLOW1)
{

static drawmode onOff = fill;
 TCNT1H = 0xC0;
 TCNT1L = 0x00;
// // Draw seconds
 GLCD_DegreeLine(60,34,sec,1,22-2,off);
 sec = sec + 6;
 GLCD_DegreeLine(60,34,sec,1,22-2,on);
 // Draw minute
 GLCD_DegreeLine(60,34,min,1,22-6,on);
 // Some simple checking....
 if (sec >= 360)
 {
   if ( onOff == fill)
     onOff = clear;
   else 
     onOff = fill;
   GLCD_Rectangle (110,95,150,125 ,onOff);       
   GLCD_Rectangle (110,95,150,125 ,on);       
   

   sec = 0;
   GLCD_DegreeLine(60,34,min,1,22-6,off);
   min = min + 6;
   GLCD_DegreeLine(60,34,min,1,22-6,on);
 }
 if (min >= 360)
 {
    min = 0;
 }
}
